/*
 * ====================================================================
 * Copyright (c) 2002-2008 The RapidSvn Group.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (in the file GPL.txt); if not, write to 
 * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 *
 * This software consists of voluntary contributions made by many
 * individuals.  For exact contribution history, see the revision
 * history and logs, available at http://rapidsvn.tigris.org/.
 * ====================================================================
 */
#ifndef _GET_ACTION_H_INCLUDED_
#define _GET_ACTION_H_INCLUDED_

// app
#include "action.hpp"
#include "get_data.hpp"

// forward declarations
namespace svn
{
  class StatusSel;
}

/**
 * This class works very much like UpdateAction.
 * There are differences:
 * - there wont be any dialogs shown
 * - the action ignores "targets" 
 * - works only on a single path that is 
 *   pass in the @a GetData structure
 */
class GetAction:public Action
{
public:
  /**
   * Constructor. This constructor creates an
   * get action, that will not prompt for
   * input in Prepare. Instead, the settings
   * in @a data will be used
   *
   * @param parent parent window
   * @param data update data
   */
  GetAction (wxWindow * parent, const GetData & data);

  virtual bool 
  Perform ();

  virtual bool 
  Prepare ();

  static bool
  CheckStatusSel (const svn::StatusSel & statusSel);

private:
  GetData m_data;
};

#endif
/* -----------------------------------------------------------------
 * local variables:
 * eval: (load-file "../rapidsvn-dev.el")
 * end:
 */
